@@ -1,6 +1,5 @@
 #!/usr/bin/python3
 from dataclasses import dataclass
-from json import dumps
 from random import randint
 from typing import Dict, List
 import pandas as pd
@@ -11,7 +10,7 @@ if __name__ == '__main__':
 from mash.filesystem.discoverable import observe
 from mash.filesystem.view import Path
 from mash.shell.shell import main
-from mash.shell.with_filesystem import ShellWithFileSystem
+from mash.shell import ShellWithFileSystem
 
 
 def generate(prefix: str, n=2):
@@ -41,22 +40,12 @@ class Team:
         return generate('t')
 
 
-# @dataclass
-# class Department:
-#     teams: List[Team]
-
-#     @staticmethod
-#     def get_all(*_) -> List[type]:
-#         return generate('department')
-
-
 @dataclass
 class Department:
     teams: List[Team]
 
     @staticmethod
     def refresh(*_) -> bool:
-        # generate.cache_clear()
         return 0
 
     @staticmethod
